==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/biome/SBNetherBiomes.java <==
package net.invictusslayer.slayersbeasts.world.level.biome;

import net.minecraft.class_1143;
import net.minecraft.class_1959;
import net.minecraft.class_2398;
import net.minecraft.class_2400;
import net.minecraft.class_2893;
import net.minecraft.class_2922;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3864;
import net.minecraft.class_4761;
import net.minecraft.class_4763;
import net.minecraft.class_4967;
import net.minecraft.class_4968;
import net.minecraft.class_5463;
import net.minecraft.class_5483;
import net.minecraft.class_5485;
import net.minecraft.class_6796;
import net.minecraft.class_6814;
import net.minecraft.class_6815;
import net.minecraft.class_6816;
import net.minecraft.class_6880;
import net.minecraft.class_7871;
import net.minecraft.world.level.biome.*;

public class SBNetherBiomes {
	public static class_1959 toxicJungle(class_7871<class_6796> features, class_7871<class_2922<?>> carvers) {
		class_5483.class_5496 mobSettings = new class_5483.class_5496();

		class_5485.class_5495 biomeSettings = new class_5485.class_5495(features, carvers);
		globalNetherGeneration(biomeSettings);
		class_3864.method_24382(biomeSettings);
		return biome(4694878, class_2398.field_28802, 0.025F, mobSettings, biomeSettings, class_3417.field_22461, class_3417.field_22462, class_3417.field_22460, class_3417.field_23797);
	}

	private static class_1959 biome(int fogColor, class_2400 particle, float particleChance, class_5483.class_5496 mobSettings, class_5485.class_5495 biomeSettings, class_6880<class_3414> loopSound, class_6880<class_3414> moodSound, class_6880<class_3414> additionsSound, class_6880<class_3414> music) {
		class_4763.class_4764 biomeEffects = new class_4763.class_4764().method_24395(4159204).method_24397(329011).method_24392(fogColor).method_30820(SBOverworldBiomes.calculateSkyColor(2.0F)).method_24393(new class_4761(particle, particleChance)).method_24942(loopSound).method_24943(new class_4968(moodSound, 6000, 8, 2.0D)).method_24944(new class_4967(additionsSound, 0.0111D)).method_27346(class_1143.method_27283(music));
		return new class_1959.class_1960().method_48164(false).method_8747(2.0F).method_8727(0.0F).method_30777(class_1959.class_5484.field_26407).method_24379(biomeEffects.method_24391()).method_30974(mobSettings.method_31007()).method_30973(biomeSettings.method_46671()).method_30972();
	}

	private static void globalNetherGeneration(class_5485.class_5495 biomeSettings) {
		biomeSettings.method_30991(class_2893.class_2894.field_13169, class_5463.field_25947);
		biomeSettings.method_30992(class_2893.class_2895.field_13178, class_6814.field_36015);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36035);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36038);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36037);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36023);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36024);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6816.field_36052);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36033);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/biome/SBNetherBiomes.java <==
package net.invictusslayer.slayersbeasts.world.level.biome;

import net.minecraft.class_1143;
import net.minecraft.class_1959;
import net.minecraft.class_2398;
import net.minecraft.class_2400;
import net.minecraft.class_2893;
import net.minecraft.class_2922;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3864;
import net.minecraft.class_4761;
import net.minecraft.class_4763;
import net.minecraft.class_4967;
import net.minecraft.class_4968;
import net.minecraft.class_5463;
import net.minecraft.class_5483;
import net.minecraft.class_5485;
import net.minecraft.class_6796;
import net.minecraft.class_6814;
import net.minecraft.class_6815;
import net.minecraft.class_6816;
import net.minecraft.class_6880;
import net.minecraft.class_7871;
import net.minecraft.world.level.biome.*;

public class SBNetherBiomes {
	public static class_1959 toxicJungle(class_7871<class_6796> features, class_7871<class_2922<?>> carvers) {
		class_5483.class_5496 mobSettings = new class_5483.class_5496();

		class_5485.class_5495 biomeSettings = new class_5485.class_5495(features, carvers);
		globalNetherGeneration(biomeSettings);
		class_3864.method_24382(biomeSettings);
		return biome(4694878, class_2398.field_28802, 0.025F, mobSettings, biomeSettings, class_3417.field_22461, class_3417.field_22462, class_3417.field_22460, class_3417.field_23797);
	}

	private static class_1959 biome(int fogColor, class_2400 particle, float particleChance, class_5483.class_5496 mobSettings, class_5485.class_5495 biomeSettings, class_6880<class_3414> loopSound, class_6880<class_3414> moodSound, class_6880<class_3414> additionsSound, class_6880<class_3414> music) {
		class_4763.class_4764 biomeEffects = new class_4763.class_4764().method_24395(4159204).method_24397(329011).method_24392(fogColor).method_30820(SBOverworldBiomes.calculateSkyColor(2.0F)).method_24393(new class_4761(particle, particleChance)).method_24942(loopSound).method_24943(new class_4968(moodSound, 6000, 8, 2.0D)).method_24944(new class_4967(additionsSound, 0.0111D)).method_27346(class_1143.method_27283(music));
		return new class_1959.class_1960().method_48164(false).method_8747(2.0F).method_8727(0.0F).method_30777(class_1959.class_5484.field_26407).method_24379(biomeEffects.method_24391()).method_30974(mobSettings.method_31007()).method_30973(biomeSettings.method_46671()).method_30972();
	}

	private static void globalNetherGeneration(class_5485.class_5495 biomeSettings) {
		biomeSettings.method_30991(class_5463.field_25947);
		biomeSettings.method_30992(class_2893.class_2895.field_13178, class_6814.field_36015);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36035);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36038);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36037);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36023);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36024);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6816.field_36052);
		biomeSettings.method_30992(class_2893.class_2895.field_13177, class_6815.field_36033);
	}
}
